@@ -61,7 +61,7 @@ class DupeDict(dict[Any, Any]):
 		A helper function to convert dupedict into something that is serializable
 		by the json module. And in this case that's a list.
 		"""
-		return list(self)
+		return json.dumps(list(self))
 
 class JsonEncoder:
 	@staticmethod
@@ -92,7 +92,10 @@ class JsonEncoder:
 		elif type(obj) == bytes:
 			return obj.decode()
 		elif hasattr(obj, 'json'):
-			return obj.json()
+			try:
+				return json.loads(obj.json())
+			except TypeError:
+				raise TypeError(f"Could not convert JSON data returned by {obj} back into a Python JSON serializable structure.")
 		elif isinstance(obj, (list, set, tuple)):
 			return [json.loads(json.dumps(item, cls=JSON)) for item in obj]
 		else:
